@@ -1,3 +1,17 @@
+#  File ergm/R/ergm.Cprepare.R
+#  Part of the statnet package, http://statnetproject.org
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) in
+#    http://statnetproject.org/attribution
+#
+# Copyright 2003 Mark S. Handcock, University of Washington
+#                David R. Hunter, Penn State University
+#                Carter T. Butts, University of California - Irvine
+#                Steven M. Goodreau, University of Washington
+#                Martina Morris, University of Washington
+# Copyright 2007 The statnet Development Team
+######################################################################
 ergm.Cprepare <- function(nw, m) 
 {
   # Build an object called Clist that contains all the necessary
@@ -30,7 +44,7 @@ ergm.Cprepare <- function(nw, m)
   mo<-m$terms 
   
   Clist$nterms<-length(mo)
-  Clist$nparam<-0
+  Clist$nstats<-0
   Clist$fnamestring<-""
   Clist$snamestring<-""
   Clist$inputs<-numeric(0)
@@ -41,7 +55,7 @@ ergm.Cprepare <- function(nw, m)
                                  ifelse(is.null(mo[[i]]$soname), "ergm",
                                         mo[[i]]$soname))
       Clist$inputs <- c(Clist$inputs, mo[[i]]$inputs)
-      Clist$nparam <- Clist$nparam + mo[[i]]$inputs[2]
+      Clist$nstats <- Clist$nstats + mo[[i]]$inputs[2]
     }
   }
   while (substring(Clist$fnamestring, 1, 1)==" ")
