@@ -1,3 +1,17 @@
+#  File ergm/R/ergm.utility.R
+#  Part of the statnet package, http://statnetproject.org
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) in
+#    http://statnetproject.org/attribution
+#
+# Copyright 2003 Mark S. Handcock, University of Washington
+#                David R. Hunter, Penn State University
+#                Carter T. Butts, University of California - Irvine
+#                Steven M. Goodreau, University of Washington
+#                Martina Morris, University of Washington
+# Copyright 2007 The statnet Development Team
+######################################################################
 ostar2deg <- function(object, ninflast=TRUE){
  nnodes <- network.size(object$newnetwork)
  nodeg <- paste("odeg",1:(nnodes-1),sep="")
@@ -334,3 +348,15 @@ statnet.edit <- function(name,package=c("statnet","ergm","network")){
   }
   invisible(filepath)
 }
+
+safeupdate.formula<-function (old, new, ...){
+  tmp <- .Internal(update.formula(as.formula(old), as.formula(new)))
+  out <- formula(terms.formula(tmp, simplify = FALSE))
+  return(out)
+}
+
+copy.named<-function(x){
+  y<-list()
+  for(name in names(x)) y[[name]]<-x[[name]]
+  y
+}
